# Change Log

All notable changes to this project will be documented in this file.
This project adheres to [Semantic Versioning](http://semver.org/).

## [Unreleased]

## [1.0.0] - 2016-07-18

### Changed
- default.yaml is not required and will not loaded automatically.
- environment configs can be a list of files.
- No exit on exeption.
- Testing is more verbose.

## [0.1.4] - 2016-07-06

### Fixed
- Include README in release.

## [0.1.3] - 2016-07-06

### Added
- Append "/" to path if not present.

### Changed
- Changelog format.
- Readme format.
- Empty files will return an empty dictionary instead of parsing error.

### Fixed
- Missing changelog for 0.1.2.
- Changelog wording.

## [0.1.2] - 2016-07-05 [YANKED]

### Fixed
- Mark internal functions as private.


## [0.1.1] - 2016-07-05 [YANKED]

### Fixed
- Add Manifest.in to include version.py.

## 0.1.0 - 2016-07-05 [YANKED]

First release of Eliza.

### Added
- Loading config files.
- Reading secrets from vault.
- Reading environment variables.

This changelog is inspired by [keepachangelog.com](http://http://keepachangelog.com/de/)

[Unreleased]: https://github.com/redvox/Eliza/compare/1.0.0...HEAD
[0.1.1]: https://github.com/redvox/Eliza/compare/0.1.0...0.1.1
[0.1.2]: https://github.com/redvox/Eliza/compare/0.1.1...0.1.2
[0.1.3]: https://github.com/redvox/Eliza/compare/0.1.2...0.1.3
[0.1.4]: https://github.com/redvox/Eliza/compare/0.1.3...0.1.4
[1.0.0]: https://github.com/redvox/Eliza/compare/0.1.4...1.0.0
